@@ -79,7 +79,7 @@ class BaseBenchmark(ABC):
         name (str): The name of the dataset.
         task (str): The type of task to be benchmarked.
         metric_names (dict): The names of the metrics.
-        id2label (dict or None): A dictionary converting indices to labels.
+        id2label (list or None): A list converting indices to labels.
         label2id (dict or None): A dictionary converting labels to indices.
         num_labels (int or None): The number of labels in the dataset.
         label_synonyms (list of lists of str): Synonyms of the dataset labels.
@@ -141,6 +141,24 @@ class BaseBenchmark(ABC):
         if verbose:
             tf_logging.set_verbosity_warning()
 
+    @staticmethod
+    def _get_model_task(task: Optional[str]) -> str:
+        '''Get the task of the model.
+
+        Args:
+            task (str or None): The task of the model.
+
+        Returns:
+            str: The task of the model.
+        '''
+        pretrained_tasks = ['fill-mask',
+                            'sentence-similarity',
+                            'feature-extraction']
+        if task is None or task in pretrained_tasks:
+            return 'fill-mask'
+        else:
+            return task
+
     def _get_model_class(self, framework: str) -> _BaseAutoModelClass:
         return MODEL_CLASSES[framework][self.task]
 
@@ -402,7 +420,7 @@ class BaseBenchmark(ABC):
                         # exception
                         if num_new_labels == self.num_labels:
                             if len(set(flat_old_synonyms)
-                                    .intersection(old_id2label)) == 0:
+                                   .intersection(old_id2label)) == 0:
                                 msg = ('The model has not been trained on '
                                        'any of the labels in the dataset, or '
                                        'synonyms thereof.')
@@ -714,7 +732,7 @@ class BaseBenchmark(ABC):
         # Extract a single valid task on which the model has been trained. If
         # no task has been specified on the model card then assume that it is
         # 'fill-mask'
-        task = tasks[0] if len(tasks) > 0 else 'fill-mask'
+        task = self._get_model_task(tasks[0]) if len(tasks) else 'fill-mask'
 
         return dict(framework=framework, task=task)
 
